// IsingSimulation.cpp: implementation of the IsingSimulation class.
//
//////////////////////////////////////////////////////////////////////

#include "IsingSimulation.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
// XXX #define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

IsingSimulation::IsingSimulation()
{
	S = new SpinLattice(100,100);
	S->setRandom(1);
	spinDynamics = new SpinDynamics(S);

	SetMagneticField(0.0);
	SetTemperature(1.0);
	SetTime(0.0);

}

IsingSimulation::~IsingSimulation()
{
	delete S;
	delete spinDynamics;
}

SpinLattice * IsingSimulation::GetLattice()		// No const! Allow people outside to reset spins [for now!]
{
	return S;
}

void IsingSimulation::SetHeightWidth(int height, int width)
{
	if (S->GetWidth() != width || S->GetHeight() != height)
	{
		delete S;
		S = new SpinLattice(height,width);
		S->setRandom(1);
		spinDynamics->ResetLattice(S);
	}
}

double IsingSimulation::Sweep()
{
	time += spinDynamics->Sweep();
	return time;
}

void IsingSimulation::SetTemperature(double temperature)
{
	this->temperature = temperature;
	spinDynamics->SetTemperature(temperature);
}

void IsingSimulation::SetMagneticField(double magneticField)
{
	this->magneticField = magneticField;
	spinDynamics->SetMagneticField(magneticField);
}
